pub struct CommitRefParams {
pub owner: Option<String>,
pub repo: String,
pub sha: String,
}Fields
owner: Option<String>repo: Stringsha: StringTrait Implementations
Sourceimpl Debug for CommitRefParams
impl Debug for CommitRefParams
Sourceimpl<'de> Deserialize<'de> for CommitRefParams
impl<'de> Deserialize<'de> for CommitRefParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommitRefParams
impl JsonSchema for CommitRefParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommitRefParams
impl RefUnwindSafe for CommitRefParams
impl Send for CommitRefParams
impl Sync for CommitRefParams
impl Unpin for CommitRefParams
impl UnsafeUnpin for CommitRefParams
impl UnwindSafe for CommitRefParams