pub struct FileContentsParams {
pub owner: Option<String>,
pub repo: String,
pub path: String,
pub git_ref: Option<String>,
}Fields
owner: Option<String>repo: Stringpath: Stringgit_ref: Option<String>Trait Implementations
Sourceimpl Debug for FileContentsParams
impl Debug for FileContentsParams
Sourceimpl<'de> Deserialize<'de> for FileContentsParams
impl<'de> Deserialize<'de> for FileContentsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FileContentsParams
impl JsonSchema for FileContentsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FileContentsParams
impl RefUnwindSafe for FileContentsParams
impl Send for FileContentsParams
impl Sync for FileContentsParams
impl Unpin for FileContentsParams
impl UnsafeUnpin for FileContentsParams
impl UnwindSafe for FileContentsParams