pub struct IssueParams {
pub owner: Option<String>,
pub repo: String,
pub issue_number: u64,
}Fields
owner: Option<String>repo: Stringissue_number: u64Trait Implementations
Sourceimpl Debug for IssueParams
impl Debug for IssueParams
Sourceimpl<'de> Deserialize<'de> for IssueParams
impl<'de> Deserialize<'de> for IssueParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IssueParams
impl JsonSchema for IssueParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IssueParams
impl RefUnwindSafe for IssueParams
impl Send for IssueParams
impl Sync for IssueParams
impl Unpin for IssueParams
impl UnsafeUnpin for IssueParams
impl UnwindSafe for IssueParams