pub struct ListIssuesParams {
pub owner: Option<String>,
pub repo: String,
pub state: Option<String>,
pub labels: Option<String>,
pub per_page: Option<u32>,
}Fields
owner: Option<String>repo: Stringstate: Option<String>labels: Option<String>per_page: Option<u32>Trait Implementations
Sourceimpl Debug for ListIssuesParams
impl Debug for ListIssuesParams
Sourceimpl<'de> Deserialize<'de> for ListIssuesParams
impl<'de> Deserialize<'de> for ListIssuesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListIssuesParams
impl JsonSchema for ListIssuesParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListIssuesParams
impl RefUnwindSafe for ListIssuesParams
impl Send for ListIssuesParams
impl Sync for ListIssuesParams
impl Unpin for ListIssuesParams
impl UnsafeUnpin for ListIssuesParams
impl UnwindSafe for ListIssuesParams