pub struct ListPullsParams {
pub owner: Option<String>,
pub repo: String,
pub state: Option<String>,
pub per_page: Option<u32>,
}Fields
owner: Option<String>repo: Stringstate: Option<String>per_page: Option<u32>Trait Implementations
Sourceimpl Debug for ListPullsParams
impl Debug for ListPullsParams
Sourceimpl<'de> Deserialize<'de> for ListPullsParams
impl<'de> Deserialize<'de> for ListPullsParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListPullsParams
impl JsonSchema for ListPullsParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListPullsParams
impl RefUnwindSafe for ListPullsParams
impl Send for ListPullsParams
impl Sync for ListPullsParams
impl Unpin for ListPullsParams
impl UnsafeUnpin for ListPullsParams
impl UnwindSafe for ListPullsParams