pub struct PullParams {
pub owner: Option<String>,
pub repo: String,
pub pr_number: u64,
}Fields
owner: Option<String>repo: Stringpr_number: u64Trait Implementations
Sourceimpl Debug for PullParams
impl Debug for PullParams
Sourceimpl<'de> Deserialize<'de> for PullParams
impl<'de> Deserialize<'de> for PullParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PullParams
impl JsonSchema for PullParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PullParams
impl RefUnwindSafe for PullParams
impl Send for PullParams
impl Sync for PullParams
impl Unpin for PullParams
impl UnsafeUnpin for PullParams
impl UnwindSafe for PullParams