pub struct RepoPageParams {
pub owner: Option<String>,
pub repo: String,
pub per_page: Option<u32>,
}Fields
owner: Option<String>repo: Stringper_page: Option<u32>Trait Implementations
Sourceimpl Debug for RepoPageParams
impl Debug for RepoPageParams
Sourceimpl<'de> Deserialize<'de> for RepoPageParams
impl<'de> Deserialize<'de> for RepoPageParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RepoPageParams
impl JsonSchema for RepoPageParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RepoPageParams
impl RefUnwindSafe for RepoPageParams
impl Send for RepoPageParams
impl Sync for RepoPageParams
impl Unpin for RepoPageParams
impl UnsafeUnpin for RepoPageParams
impl UnwindSafe for RepoPageParams