pub struct SearchCodeParams {
pub query: String,
pub owner: Option<String>,
pub repo: Option<String>,
pub per_page: Option<u32>,
}Fields
query: Stringowner: Option<String>repo: Option<String>per_page: Option<u32>Trait Implementations
Sourceimpl Debug for SearchCodeParams
impl Debug for SearchCodeParams
Sourceimpl<'de> Deserialize<'de> for SearchCodeParams
impl<'de> Deserialize<'de> for SearchCodeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchCodeParams
impl JsonSchema for SearchCodeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchCodeParams
impl RefUnwindSafe for SearchCodeParams
impl Send for SearchCodeParams
impl Sync for SearchCodeParams
impl Unpin for SearchCodeParams
impl UnsafeUnpin for SearchCodeParams
impl UnwindSafe for SearchCodeParams